// LNP/BP Core Library implementing LNPBP specifications & standards
// Written in 2020 by
//     Dr. Maxim Orlovsky <orlovsky@pandoracore.com>
//
// To the extent possible under law, the author(s) have dedicated all
// copyright and related and neighboring rights to this software to
// the public domain worldwide. This software is distributed without
// any warranty.
//
// You should have received a copy of the MIT License
// along with this software.
// If not, see <https://opensource.org/licenses/MIT>.

//! BOLT-8 related structures and functions covering Lightning network
//! transport layer

mod init;
mod local_node;
pub mod node_addr;
pub mod noise;
#[allow(clippy::module_inception)]
mod session;
mod transcoders;

pub use init::{Accept, Connect};
pub use local_node::LocalNode;
#[cfg(not(feature = "zmq"))]
pub use node_addr::ZmqType;
pub use node_addr::{
    NodeAddr, PartialNodeAddr, RemoteNodeAddr, ToNodeAddr, ToRemoteNodeAddr,
};
pub use noise::{
    HandshakeError, NoiseDecryptor, NoiseEncryptor, NoiseTranscoder,
};
pub use session::{Input, Output, Raw, RawInput, RawOutput, Session, Split};
pub use transcoders::{
    Decrypt, DecryptionError, Encrypt, PlainTranscoder, Transcode,
};
